@@ -1,7 +1,7 @@
 use v5.10.0;
 package JMAP::Tester::Response::Sentence::Set;
 # ABSTRACT: the kind of sentence you get in reply to a setFoos call
-$JMAP::Tester::Response::Sentence::Set::VERSION = '0.012';
+$JMAP::Tester::Response::Sentence::Set::VERSION = '0.013';
 use Moo;
 extends 'JMAP::Tester::Response::Sentence';
 
@@ -160,7 +160,7 @@ sub assert_no_errors {
     );
   }
 
-  return unless @errors;
+  return $self unless @errors;
 
   abort({
     message     => "errors found in " . $self->name . " sentence",
@@ -182,7 +182,7 @@ JMAP::Tester::Response::Sentence::Set - the kind of sentence you get in reply to
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 OVERVIEW
 
